@@ -1,8 +1,7 @@
+import math
 from io import BytesIO
 from typing import List, Optional, Union, Dict, Any
 
-import math
-
 from .unspent import Unspent
 from ..constants import SIGHASH, Chain
 from ..constants import TRANSACTION_VERSION, TRANSACTION_LOCKTIME, TRANSACTION_SEQUENCE, TRANSACTION_FEE_RATE, P2PKH_DUST_LIMIT
@@ -45,7 +44,7 @@ class TxInput:
         stream.write(self.sequence.to_bytes(4, 'little'))
         return stream.getvalue()
 
-    def __repr__(self) -> str:  # pragma: no cover
+    def __str__(self) -> str:  # pragma: no cover
         return f'<TxInput outpoint={self.txid}:{self.vout} satoshi={self.satoshi} locking_script={self.locking_script}>'
 
 
@@ -71,6 +70,9 @@ class TxOutput:
     def serialize(self) -> bytes:
         return self.satoshi.to_bytes(8, 'little') + self.locking_script.byte_length_varint() + self.locking_script.serialize()
 
+    def __str__(self) -> str:  # pragma: no cover
+        return f'<TxOutput satoshi={self.satoshi} locking_script={self.locking_script.hex()}>'
+
 
 class Transaction:
 
@@ -219,7 +221,7 @@ class Transaction:
             if not tx_input.unlocking_script or not bypass:
                 signatures: List[bytes] = [private_key.sign(digests[i]) for private_key in tx_input.private_keys]
                 payload = {'signatures': signatures, 'private_keys': tx_input.private_keys, 'sighash': tx_input.sighash}
-                tx_input.unlocking_script = tx_input.script_type.unlocking(**payload, **self.kwargs, **kwargs)
+                tx_input.unlocking_script = tx_input.script_type.unlocking(**payload, **{**self.kwargs, **kwargs})
         return self
 
     def satoshi_total_in(self) -> int:
@@ -250,7 +252,7 @@ class Transaction:
         for tx_input in self.tx_inputs:
             if not tx_input.private_keys:
                 raise ValueError(f"can't estimate byte length for {tx_input} without private keys")
-            estimated_length += 41 + tx_input.script_type.estimated_unlocking_byte_length(private_keys=tx_input.private_keys, **self.kwargs, **kwargs)
+            estimated_length += 41 + tx_input.script_type.estimated_unlocking_byte_length(private_keys=tx_input.private_keys, **{**self.kwargs, **kwargs})
         for tx_output in self.tx_outputs:
             estimated_length += 8 + len(tx_output.locking_script.byte_length_varint()) + tx_output.locking_script.byte_length()
         return estimated_length
